@@ -19,14 +19,13 @@
 
 *****************************************************************************/
 
-#include <qapplication.h>
-#include <qtextcodec.h>
-
 #include "qsynthAbout.h"
 #include "qsynthOptions.h"
 #include "qsynthMainForm.h"
 
-#include "config.h"
+#include <qapplication.h>
+#include <qtextcodec.h>
+
 
 //-------------------------------------------------------------------------
 // main - The main program trunk.
@@ -55,14 +54,15 @@ int main ( int argc, char **argv )
         app.quit();
         return 1;
     }
-    
+
     // Construct, setup and show the main form.
     qsynthMainForm w;
+    app.setMainWidget(&w);
     w.setup(&settings);
     w.show();
 
     // Register the quit signal/slot.
-    app.connect(&app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()));
+    // app.connect(&app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()));
 
     return app.exec();
 }
