@@ -1,7 +1,7 @@
 // qsynthMeter.h
 //
 /****************************************************************************
-   Copyright (C) 2004, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2004-2005, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,13 +22,8 @@
 #ifndef __qsynthMeter_h
 #define __qsynthMeter_h
 
-#include <qhbox.h>
-#include <qlayout.h>
 #include <qptrlist.h>
-#include <qpixmap.h>
-#include <qpainter.h>
-
-#include <math.h>
+#include <qhbox.h>
 
 // Color/level indexes.
 #define QSYNTHMETER_OVER    0
@@ -60,10 +55,6 @@ public:
     // Default destructor.
     ~qsynthMeterScale();
 
-    // IEC scaling helpers.
-    int iec_scale (float dB);
-    int iec_level (int iIndex);
-
 protected:
 
     // Specific event handlers.
@@ -73,7 +64,7 @@ protected:
 private:
 
     // Draw IEC scale line and label.
-    void drawLineLabel(QPainter& p, int y, const char* pszLabel);
+    void drawLineLabel(QPainter *p, int y, const char* pszLabel);
 
     // Local instance variables.
     qsynthMeter *m_pMeter;
@@ -100,6 +91,9 @@ public:
     // Frame value accessors.
     void setValue(float fValue);
 
+	// Reset peak holder.
+	void peakReset();
+
 protected:
 
     // Specific event handlers.
@@ -112,9 +106,12 @@ private:
     qsynthMeter *m_pMeter;
     // Running variables.
     float m_fValue;
+    int   m_iValue;
+    float m_fValueDecay;
     int   m_iPeak;
+    int   m_iPeakHold;
+    float m_fPeakDecay;
     int   m_iPeakColor;
-    float m_fDecayRate;
 };
 
 
@@ -133,20 +130,27 @@ public:
     ~qsynthMeter();
 
     // Port count accessor.
-    int portCount();
+    int portCount() const;
 
     // Value proxy.    
     void setValue(int iPort, float fValue);
 
     // IEC scale accessors.
-    int iec_scale(float dB);
-    int iec_level(int iIndex);
+    int iec_scale(float dB) const;
+    int iec_level(int iIndex) const;
 
     // Slot refreshment.
     void refresh();
 
     // Common resource accessors.
-    QColor& color(int iIndex);
+    const QColor& color(int iIndex) const;
+
+	// Peak falloff mode setting.
+	void setPeakFalloff(int bPeakFalloff);
+	int peakFalloff() const;
+
+	// Reset peak holder.
+	void peakReset();
 
 protected:
 
@@ -163,6 +167,9 @@ private:
     int                m_iLevels[QSYNTHMETER_LEVELS];
     QColor            *m_pColors[QSYNTHMETER_COLORS];
     float              m_fScale;
+
+	// Peak falloff mode setting (0=no peak falloff).
+    int m_iPeakFalloff;
 };
 
     
