@@ -20,6 +20,8 @@
 
 *****************************************************************************/
 
+#include "qsynthAbout.h"
+
 #include <qvalidator.h>
 #include <qmessagebox.h>
 #include <qpopupmenu.h>
@@ -28,10 +30,6 @@
 #include <qfontdialog.h>
 #include <qlistbox.h>
 
-#include "config.h"
-
-#include "qsynthAbout.h"
-
 
 // Our local parameter data struct.
 struct qsynth_settings_data
@@ -45,7 +43,7 @@ struct qsynth_settings_data
 static void qsynth_settings_foreach_option ( void *pvData, char *, char *pszOption )
 {
     qsynth_settings_data *pData = (qsynth_settings_data *) pvData;
-    
+
     pData->options.append(pszOption);
 }
 
@@ -209,8 +207,10 @@ void qsynthSetupForm::setup ( qsynthOptions *pOptions, qsynthEngine *pEngine, bo
 
     // Start clean?
     m_iDirtyCount = 0;
-    if (bNew)
-        m_iDirtyCount++;
+	if (bNew) {
+		m_pSetup->realize();
+		m_iDirtyCount++;
+	}
     // Avoid nested changes.
     m_iDirtySetup++;
 
@@ -380,7 +380,8 @@ void qsynthSetupForm::reject (void)
 
     // Check if there's any pending changes...
     if (m_iDirtyCount > 0) {
-        switch (QMessageBox::warning(this, tr("Warning"),
+        switch (QMessageBox::warning(this,
+			QSYNTH_TITLE ": " + tr("Warning"),
             tr("Some settings have been changed.") + "\n\n" +
             tr("Do you want to apply the changes?"),
             tr("Apply"), tr("Discard"), tr("Cancel"))) {
@@ -491,27 +492,40 @@ void qsynthSetupForm::stabilizeForm (void)
 // Soundfont view context menu handler.
 void qsynthSetupForm::contextMenu( QListViewItem *pItem, const QPoint& pos, int )
 {
-    int iItemID;
+	int iItemID;
 
-    // Build the soundfont context menu...
-    QPopupMenu* pContextMenu = new QPopupMenu(this);
+	// Build the soundfont context menu...
+	QPopupMenu* pContextMenu = new QPopupMenu(this);
 
-    iItemID = pContextMenu->insertItem(tr("Open..."), this, SLOT(openSoundFont()));
-    pContextMenu->insertSeparator();
-    bool bEnabled = (pItem != NULL);
-    iItemID = pContextMenu->insertItem(tr("Edit"), this, SLOT(editSoundFont()));
-    pContextMenu->setItemEnabled(iItemID, bEnabled && pItem->renameEnabled(2));
-    iItemID = pContextMenu->insertItem(tr("Remove"), this, SLOT(removeSoundFont()));
-    pContextMenu->setItemEnabled(iItemID, bEnabled);
-    pContextMenu->insertSeparator();
-    iItemID = pContextMenu->insertItem(tr("Move Up"), this, SLOT(moveUpSoundFont()));
-    pContextMenu->setItemEnabled(iItemID, (bEnabled && pItem->itemAbove() != NULL));
-    iItemID = pContextMenu->insertItem(tr("Move Down"), this, SLOT(moveDownSoundFont()));
-    pContextMenu->setItemEnabled(iItemID, (bEnabled && pItem->nextSibling() != NULL));
+	iItemID = pContextMenu->insertItem(
+		QIconSet(QPixmap::fromMimeSource("open1.png")),
+		tr("Open..."), this, SLOT(openSoundFont()));
+	pContextMenu->insertSeparator();
+	bool bEnabled = (pItem != NULL);
+	iItemID = pContextMenu->insertItem(
+		QIconSet(QPixmap::fromMimeSource("edit1.png")),
+		tr("Edit"), this, SLOT(editSoundFont()));
+	pContextMenu->setItemEnabled(iItemID,
+		bEnabled && pItem->renameEnabled(2));
+	iItemID = pContextMenu->insertItem(
+		QIconSet(QPixmap::fromMimeSource("remove1.png")),
+		tr("Remove"), this, SLOT(removeSoundFont()));
+	pContextMenu->setItemEnabled(iItemID, bEnabled);
+	pContextMenu->insertSeparator();
+	iItemID = pContextMenu->insertItem(
+		QIconSet(QPixmap::fromMimeSource("up1.png")),
+		tr("Move Up"), this, SLOT(moveUpSoundFont()));
+	pContextMenu->setItemEnabled(iItemID,
+		(bEnabled && pItem->itemAbove() != NULL));
+	iItemID = pContextMenu->insertItem(
+		QIconSet(QPixmap::fromMimeSource("down1.png")),
+		tr("Move Down"), this, SLOT(moveDownSoundFont()));
+	pContextMenu->setItemEnabled(iItemID,
+		(bEnabled && pItem->nextSibling() != NULL));
 
-    pContextMenu->exec(pos);
-    
-    delete pContextMenu;
+	pContextMenu->exec(pos);
+
+	delete pContextMenu;
 }
 
 
@@ -531,12 +545,12 @@ void qsynthSetupForm::refreshSoundFonts (void)
 void qsynthSetupForm::openSoundFont()
 {
     QStringList soundfonts = QFileDialog::getOpenFileNames(
-            tr("Soundfont files") + " (*.sf2 *.SF2)",   // Filter (SF2 files)
-            m_pOptions->sSoundFontDir,                  // Start here.
-            this, 0,                                    // Parent and name (none)
-            tr("Soundfont files")                       // Caption.
+		tr("Soundfont files") + " (*.sf2 *.SF2)",   // Filter (SF2 files)
+		m_pOptions->sSoundFontDir,                  // Start here.
+		this, 0,                                    // Parent and name (none)
+		QSYNTH_TITLE ": " + tr("Soundfont files")	// Caption.
     );
-    
+
     QListViewItem *pItem = NULL;
     // For avery selected soundfont to load...
     for (QStringList::Iterator iter = soundfonts.begin(); iter != soundfonts.end(); iter++) {
@@ -546,7 +560,8 @@ void qsynthSetupForm::openSoundFont()
         if (::fluid_is_soundfont(pszFilename)) {
             // Check if not already there...
             if (SoundFontListView->findItem(sSoundFont, 1) &&
-                QMessageBox::warning(this, tr("Warning"),
+                QMessageBox::warning(this,
+					QSYNTH_TITLE ": " + tr("Warning"),
                     tr("Soundfont file already on list") + ":\n\n" +
                     "\"" + sSoundFont + "\"\n\n" +
                     tr("Add anyway?"),
@@ -577,7 +592,8 @@ void qsynthSetupForm::openSoundFont()
             }
         }
         else {
-            QMessageBox::critical(this, tr("Error"),
+            QMessageBox::critical(this,
+				QSYNTH_TITLE ": " + tr("Error"),
                 tr("Failed to add soundfont file") + ":\n\n" +
                 "\"" + sSoundFont + "\"\n\n" +
                 tr("Please, check for a valid soundfont file."),
